@@ -24,42 +24,39 @@
 /* cldmgr_init - initializes child management
  * returns FALSE if trouble encountered.
  */
-extern bool_t cldmgr_init( void );
+extern bool_t cldmgr_init(void);
 
 /* cldmgr_create - creates a child thread. returns FALSE if trouble
  * encountered
  */
-extern bool_t cldmgr_create( int ( * entry )( void *arg1 ),
-			     u_intgen_t inh,
+extern bool_t cldmgr_create(int (*entry)(void *arg1),
 			     ix_t streamix,
 			     char *descstr,
-			     void *arg1 );
+			     void *arg1);
 
 /* cldmgr_stop - asks all children to gracefully terminate, at the next
  * convenient point in their normal processing loop.
  */
-extern void cldmgr_stop( void );
+extern void cldmgr_stop(void);
 
-/* cldmgr_died - tells the child manager that the child died
+/* cldmgr_join - join child threads that have exited.
+ * returns EXIT_NORMAL if all exited normally (or no threads have exited),
+ * EXIT_FAULT if any threads requested a core dump, or another EXIT_*
+ * value if any threads exited abnormally.
  */
-extern void cldmgr_died( pid_t pid );
+extern int cldmgr_join(void);
 
 /* cldmgr_stop_requested - returns TRUE if the child should gracefully
  * terminate.
  */
-extern bool_t cldmgr_stop_requested( void );
-
-/* cldmgr_pid2streamix - retrieves the stream index. returns -1 if
- * not associated with any stream.
- */
-extern intgen_t cldmgr_pid2streamix( pid_t pid );
+extern bool_t cldmgr_stop_requested(void);
 
 /* cldmgr_remainingcnt - returns number of children remaining
  */
-extern size_t cldmgr_remainingcnt( void );
+extern size_t cldmgr_remainingcnt(void);
 
 /* checks if any children serving any other streams are still alive
  */
-extern bool_t cldmgr_otherstreamsremain( ix_t streamix );
+extern bool_t cldmgr_otherstreamsremain(ix_t streamix);
 
 #endif /* CLDMGR_H */
