@@ -16,10 +16,24 @@
  * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <xfs/xfs.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <string.h>
+#include <errno.h>
+#include <assert.h>
+#include <uuid/uuid.h>
 #include <attr/attributes.h>
+#include <xfs/xfs.h>
 #include <xfs/jdm.h>
 
+#include <string.h>
+
+#include "config.h"
+
+#include "types.h"
 #include "hsmapi.h"
 #include "mlog.h"
 
@@ -60,12 +74,12 @@ typedef	struct {
 	u_char	regcnt[2];	/* number of regions in MSB form */
 } XFSattrvalue1_t;
 
-#define	MIN_FORMAT1_ATTR_LEN	( sizeof(XFSattrvalue1_t) + \
-				  sizeof(XFSattrregion_t) )
+#define	MIN_FORMAT1_ATTR_LEN	(sizeof(XFSattrvalue1_t) + \
+				  sizeof(XFSattrregion_t))
 
 /* supported fsys values */
 
-/* XFS DMAPI (w/o MMR ) */
+/* XFS DMAPI (w/o MMR) */
 #define	FSYS_TYPE_XFS		1
 
 /* supported version values */
@@ -94,16 +108,16 @@ typedef	struct {
 #define	DM_EVENT_TRUNCATE	18
 #define	DM_EVENT_DESTROY	20
 
- /* Interesting bit combinations within the bs_dmevmask field of xfs_bstat_t:
+/* Interesting bit combinations within the bs_dmevmask field of struct xfs_bstat
  * OFL, UNM, and PAR files have exactly these bits set.
  * DUL and MIG files have all but the DM_EVENT_READ bit set */
-#define DMF_EV_BITS	( (1<<DM_EVENT_DESTROY) | \
+#define DMF_EV_BITS	((1<<DM_EVENT_DESTROY) | \
 			  (1<<DM_EVENT_READ)    | \
 			  (1<<DM_EVENT_WRITE)   | \
-			  (1<<DM_EVENT_TRUNCATE) )
+			  (1<<DM_EVENT_TRUNCATE))
 
 /* OFL file's managed region event flags */
-#define DMF_MR_FLAGS	( 0x1 | 0x2 | 0x4 )
+#define DMF_MR_FLAGS	(0x1 | 0x2 | 0x4)
 
 /* The following definitions provide the internal format of the hsm_fs_ctxt_t
    and hsm_f_ctxt_t structures, respectively.
@@ -132,7 +146,7 @@ typedef	struct	{
 static inline void
 msb_store(
 	u_char		*dest,
-	u_int64_t	src,
+	uint64_t	src,
 	int		length)
 {
         int             i;
@@ -150,12 +164,12 @@ msb_store(
 * Returns
 *	value
 ******************************************************************************/
-static inline u_int64_t
+static inline uint64_t
 msb_load(
 	u_char		*src,
 	int		length)
 {
-        u_int64_t        tmp = 0;
+        uint64_t        tmp = 0;
         int             i;
 
         for (i = 0; i < length; i++) {
@@ -254,11 +268,11 @@ HsmDeleteFsysContext(
 
 extern int
 HsmEstimateFileSpace(
-	hsm_fs_ctxt_t	*fscontextp,
-	hsm_f_ctxt_t	*fcontextp,
-const	xfs_bstat_t	*statp,
-	off64_t		*bytes,
-	int		accurate)
+	hsm_fs_ctxt_t		*fscontextp,
+	hsm_f_ctxt_t		*fcontextp,
+	const struct xfs_bstat	*statp,
+	off64_t			*bytes,
+	int			accurate)
 {
 	/* If the estimate needs to be accurate, then we'll have to
 	 * pay the price and read the DMF attribute, if there is one,
@@ -338,13 +352,13 @@ const	xfs_bstat_t	*statp,
 /* ARGSUSED */
 extern int
 HsmEstimateFileOffset(
-	hsm_fs_ctxt_t	*contextp,
-const	xfs_bstat_t	*statp,
-	off64_t		bytecount,
-	off64_t		*byteoffset)
+	hsm_fs_ctxt_t		*contextp,
+	const struct xfs_bstat	*statp,
+	off64_t			bytecount,
+	off64_t			*byteoffset)
 {
-	dmf_fs_ctxt_t	*dmf_fs_ctxtp = (dmf_fs_ctxt_t *)contextp;
-	dmf_f_ctxt_t	dmf_f_ctxt;
+	dmf_fs_ctxt_t		*dmf_fs_ctxtp = (dmf_fs_ctxt_t *)contextp;
+	dmf_f_ctxt_t		dmf_f_ctxt;
 
 	/* This is an implicit HsmAllocateFileContext call. */
 
@@ -443,14 +457,14 @@ HsmDeleteFileContext(
 
 extern int
 HsmInitFileContext(
-	hsm_f_ctxt_t	*contextp,
-const	xfs_bstat_t	*statp)
+	hsm_f_ctxt_t		*contextp,
+	const struct xfs_bstat	*statp)
 {
-	dmf_f_ctxt_t	*dmf_f_ctxtp = (dmf_f_ctxt_t *)contextp;
-	XFSattrvalue0_t	*dmfattrp;
-	int		state;
-	int		error;
-	attr_multiop_t	attr_op;
+	dmf_f_ctxt_t		*dmf_f_ctxtp = (dmf_f_ctxt_t *)contextp;
+	XFSattrvalue0_t		*dmfattrp;
+	int			state;
+	int			error;
+	attr_multiop_t		attr_op;
 
 	dmf_f_ctxtp->candidate = 0; /* assume file will NOT be of interest */
 
@@ -462,7 +476,7 @@ const	xfs_bstat_t	*statp)
 	if ((statp->bs_xflags & XFS_XFLAG_HASATTR) == 0) {
 		return 0;	/* no DMF attribute exists */
 	}
-	if ((statp->bs_dmevmask & DMF_EV_BITS) == 0 ) {
+	if ((statp->bs_dmevmask & DMF_EV_BITS) == 0) {
 		return 0;	/* no interesting DMAPI bits set */
 	}
 
@@ -478,7 +492,7 @@ const	xfs_bstat_t	*statp)
 	attr_op.am_flags     = ATTR_ROOT;
 
 	error = jdm_attr_multi(dmf_f_ctxtp->fsys.fshanp,
-			       (xfs_bstat_t *)statp,
+			       (struct xfs_bstat *)statp,
 			       (char *)&attr_op,
 			       1,
 			       0);
@@ -514,7 +528,7 @@ const	xfs_bstat_t	*statp)
 		dmf_f_ctxtp->candidate = 1;
 		dmf_f_ctxtp->filesize = statp->bs_size;
 		break;
-	
+
 	default:
 		break;
 	}
@@ -522,26 +536,26 @@ const	xfs_bstat_t	*statp)
 }
 
 
-/******************************************************************************
+/*******************************************************************************
 * Name
-*	HsmModifyInode - modify a xfs_bstat_t to make a file appear offline
+*	HsmModifyInode - modify a struct xfs_bstat to make a file appear offline
 *
 * Description
 *	HsmModifyInode uses the context provided by a previous
-*	HsmInitFileContext call to determine how to modify a xfs_bstat_t
+*	HsmInitFileContext call to determine how to modify a struct xfs_bstat
 *	structure to make a dual-residency HSM file appear to be offline.
 *
 * Returns
-*	!= 0, xfs_bstat_t structure was modified.
+*	!= 0, struct xfs_bstat structure was modified.
 *	== 0, if something is wrong with the file and it should not be dumped.
-******************************************************************************/
+8******************************************************************************/
 
 extern int
 HsmModifyInode(
-	hsm_f_ctxt_t	*contextp,
-	xfs_bstat_t	*statp)
+	hsm_f_ctxt_t		*contextp,
+	struct xfs_bstat	*statp)
 {
-	dmf_f_ctxt_t	*dmf_f_ctxtp = (dmf_f_ctxt_t *)contextp;
+	dmf_f_ctxt_t		*dmf_f_ctxtp = (dmf_f_ctxt_t *)contextp;
 
 	if (dmf_f_ctxtp->candidate) {
 		statp->bs_dmevmask = DMF_EV_BITS;
@@ -571,7 +585,7 @@ HsmModifyExtentMap(
 	struct getbmapx	*bmap)
 {
 	dmf_f_ctxt_t	*dmf_f_ctxtp = (dmf_f_ctxt_t *)contextp;
-	__int64_t	length;
+	int64_t		length;
 
 	if (bmap[0].bmv_entries <= 0) {
 		return 1;	/* caller must already be at EOF */
@@ -629,7 +643,7 @@ extern int
 HsmFilterExistingAttribute(
 	hsm_f_ctxt_t	*hsm_f_ctxtp,
 const	char		*namep,		/* attribute name */
-	u_int32_t	valuesz,	/* value size */
+	uint32_t	valuesz,	/* value size */
 	int		flag,
 	int		*skip_entry)
 {
@@ -693,7 +707,7 @@ HsmAddNewAttribute(
 	int		flag,
 	char		**namepp,	/* pointer to new attribute name */
 	char		**valuepp,	/* pointer to its value */
-	u_int32_t	*valueszp)	/* pointer to the value size */
+	uint32_t	*valueszp)	/* pointer to the value size */
 {
 	dmf_f_ctxt_t	*dmf_f_ctxtp = (dmf_f_ctxt_t *)hsm_f_ctxtp;
 	XFSattrvalue1_t	*dmfattr1p = (XFSattrvalue1_t *)dmf_f_ctxtp->attrval;
@@ -721,8 +735,8 @@ HsmAddNewAttribute(
 	if (dmfattr1p->version == DMF_ATTR_FORMAT_1 &&
 	    msb_load(dmfattr1p->sitetag, sizeof(dmfattr1p->sitetag)) != 0) {
 		XFSattrregion_t *reg;
-		reg = (XFSattrregion_t *)( dmf_f_ctxtp->attrval +
-				           sizeof(XFSattrvalue1_t) );
+		reg = (XFSattrregion_t *)(dmf_f_ctxtp->attrval +
+				           sizeof(XFSattrvalue1_t));
 		dmf_f_ctxtp->attrlen = MIN_FORMAT1_ATTR_LEN;
 
 		/* make one offline region the size of the whole file */
@@ -780,7 +794,7 @@ HsmBeginRestoreFile(
 	 * remove the attribute when the file is completed.
 	 */
 	*hsm_flagp = 0;
-	if ( bstatp->bs_dmevmask && bstatp->bs_xflags & XFS_XFLAG_HASATTR ) {
+	if (bstatp->bs_dmevmask && bstatp->bs_xflags & XFS_XFLAG_HASATTR) {
 		memset(&dmattr, 0, sizeof(XFSattrvalue0_t));
 		dmattr.fsys = FSYS_TYPE_XFS;
 		msb_store(dmattr.state, DMF_ST_NOMIGR, sizeof(dmattr.state));
@@ -857,7 +871,7 @@ HsmEndRestoreFile(
 	 */
 	if (*hsm_flagp) {
 		int rv;
-		rv = attr_removef( fd, DMF_ATTR_NAME , ATTR_ROOT );
+		rv = attr_removef(fd, DMF_ATTR_NAME, ATTR_ROOT);
 		if (rv) {
 			mlog(MLOG_NORMAL | MLOG_WARNING,
 			     _("error removing temp DMF attr on %s: %s\n"),
