@@ -16,15 +16,19 @@
  * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <xfs/xfs.h>
-#include <xfs/jdm.h>
-#include "config.h"
-
+#include <unistd.h>
+#include <stdlib.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
 #include <errno.h>
 #include <dirent.h>
+#include <assert.h>
+#include <string.h>
+#include <xfs/xfs.h>
+#include <xfs/jdm.h>
+
+#include "config.h"
 
 #include "types.h"
 #include "util.h"
@@ -33,32 +37,32 @@
 
 extern size_t pgsz;
 
-intgen_t
-write_buf( char *bufp,
+int
+write_buf(char *bufp,
 	   size_t bufsz,
 	   void *contextp,
 	   gwbfp_t get_write_buf_funcp,
-	   wfp_t write_funcp )
+	   wfp_t write_funcp)
 {
 	char *mbufp;	/* buffer obtained from manager */
 	size_t mbufsz;/* size of buffer obtained from manager */
 
-	while ( bufsz ) {
+	while (bufsz) {
 		int rval;
 
-		ASSERT( bufsz > 0 );
-		mbufp = ( *get_write_buf_funcp )( contextp, bufsz, &mbufsz );
-		ASSERT( mbufsz <= bufsz );
-		if ( bufp ) {
-			(void)memcpy( ( void * )mbufp, ( void * )bufp, mbufsz );
+		assert(bufsz > 0);
+		mbufp = (*get_write_buf_funcp)(contextp, bufsz, &mbufsz);
+		assert(mbufsz <= bufsz);
+		if (bufp) {
+			(void)memcpy((void *)mbufp, (void *)bufp, mbufsz);
 		} else {
-			(void)memset( ( void * )mbufp, 0, mbufsz );
+			(void)memset((void *)mbufp, 0, mbufsz);
 		}
-		rval = ( * write_funcp )( contextp, mbufp, mbufsz );
-		if ( rval ) {
+		rval = (*write_funcp)(contextp, mbufp, mbufsz);
+		if (rval) {
 			return rval;
 		}
-		if ( bufp ) {
+		if (bufp) {
 			bufp += mbufsz;
 		}
 		bufsz -= mbufsz;
@@ -67,68 +71,68 @@ write_buf( char *bufp,
 	return 0;
 }
 
-intgen_t
-read_buf( char *bufp,
-	  size_t bufsz, 
+int
+read_buf(char *bufp,
+	  size_t bufsz,
 	  void *contextp,
 	  rfp_t read_funcp,
 	  rrbfp_t return_read_buf_funcp,
-	  intgen_t *statp )
+	  int *statp)
 {
 	char *mbufp;		/* manager's buffer pointer */
 	size_t mbufsz;	/* size of manager's buffer */
-	intgen_t nread;
+	int nread;
 
 	nread = 0;
 	*statp = 0;
-	while ( bufsz ) {
-		mbufp = ( * read_funcp )( contextp, bufsz, &mbufsz, statp );
-		if ( *statp ) {
+	while (bufsz) {
+		mbufp = (*read_funcp)(contextp, bufsz, &mbufsz, statp);
+		if (*statp) {
 			break;
 		}
-		ASSERT( mbufsz <= bufsz );
-		if ( bufp ) {
-			( void )memcpy( (void *)bufp, (void *)mbufp, mbufsz );
+		assert(mbufsz <= bufsz);
+		if (bufp) {
+			(void)memcpy((void *)bufp, (void *)mbufp, mbufsz);
 			bufp += mbufsz;
 		}
 		bufsz -= mbufsz;
-		nread += ( intgen_t )mbufsz;
-		( * return_read_buf_funcp )( contextp, mbufp, mbufsz );
+		nread += (int)mbufsz;
+		(*return_read_buf_funcp)(contextp, mbufp, mbufsz);
 	}
 
 	return nread;
 }
 
 char
-*strncpyterm( char *s1, char *s2, size_t n )
+*strncpyterm(char *s1, char *s2, size_t n)
 {
 	char *rval;
 
-	if ( n < 1 ) return 0;
-	rval = strncpy( s1, s2, n );
-	s1[ n - 1 ] = 0;
+	if (n < 1) return 0;
+	rval = strncpy(s1, s2, n);
+	s1[n - 1] = 0;
 	return rval;
 }
 
-intgen_t
-bigstat_iter( jdm_fshandle_t *fshandlep,
-	      intgen_t fsfd,
-	      intgen_t selector,
+int
+bigstat_iter(jdm_fshandle_t *fshandlep,
+	      int fsfd,
+	      int selector,
 	      xfs_ino_t start_ino,
 	      bstat_cbfp_t fp,
 	      void * cb_arg1,
 	      bstat_seekfp_t seekfp,
 	      void * seek_arg1,
-	      intgen_t *statp,
-	      bool_t ( pfp )( int ),
-	      xfs_bstat_t *buf,
-	      size_t buflenin )
+	      int *statp,
+	      bool_t (pfp)(int),
+	      struct xfs_bstat *buf,
+	      size_t buflenin)
 {
 	__s32 buflenout;
 	xfs_ino_t lastino;
-	intgen_t saved_errno;
-	intgen_t bulkstatcnt;
-        xfs_fsop_bulkreq_t bulkreq;
+	int saved_errno;
+	int bulkstatcnt;
+        struct xfs_fsop_bulkreq bulkreq;
 
 	/* stat set with return from callback func
 	 */
@@ -137,20 +141,20 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 	/* NOT COOL: open will affect root dir's access time
 	 */
 
-	mlog( MLOG_NITTY,
+	mlog(MLOG_NITTY,
 	      "bulkstat iteration initiated: start_ino == %llu\n",
-	      start_ino );
+	      start_ino);
 
 	/* quirk of the interface: I want to play in terms of the
 	 * ino to begin with, and ino 0 is not used. so, ...
 	 */
-	if ( start_ino > 0 ) {
+	if (start_ino > 0) {
 		lastino = start_ino - 1;
 	} else {
 		lastino = 0;
 	}
-	mlog( MLOG_NITTY + 1,
-	      "calling bulkstat\n" );
+	mlog(MLOG_NITTY + 1,
+	      "calling bulkstat\n");
 
 	bulkstatcnt = 0;
 	bulkreq.lastip = (__u64 *)&lastino;
@@ -158,135 +162,135 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 	bulkreq.ubuffer = buf;
 	bulkreq.ocount = &buflenout;
 	while (!ioctl(fsfd, XFS_IOC_FSBULKSTAT, &bulkreq)) {
-		xfs_bstat_t *p;
-		xfs_bstat_t *endp;
+		struct xfs_bstat *p;
+		struct xfs_bstat *endp;
 
-		if ( buflenout == 0 ) {
-			mlog( MLOG_NITTY + 1,
+		if (buflenout == 0) {
+			mlog(MLOG_NITTY + 1,
 			      "bulkstat returns buflen %d\n",
-			      buflenout );
+			      buflenout);
 			return 0;
 		}
-		mlog( MLOG_NITTY + 1,
+		mlog(MLOG_NITTY + 1,
 		      "bulkstat returns buflen %d ino %llu\n",
 		      buflenout,
-		      buf->bs_ino );
-		for ( p = buf, endp = buf + buflenout ; p < endp ; p++ ) {
-			intgen_t rval;
+		      buf->bs_ino);
+		for (p = buf, endp = buf + buflenout; p < endp; p++) {
+			int rval;
 
-			if ( p->bs_ino == 0 )
+			if (p->bs_ino == 0)
 				continue;
 
-			if ( !p->bs_nlink || !p->bs_mode ) {
+			if (!p->bs_nlink || !p->bs_mode) {
 				/* inode being modified, get synced data */
-				mlog( MLOG_NITTY + 1,
+				mlog(MLOG_NITTY + 1,
 				      "ino %llu needed second bulkstat\n",
-				      p->bs_ino );
+				      p->bs_ino);
 
-				if( bigstat_one( fsfd, p->bs_ino, p ) < 0 ) {
-				    mlog( MLOG_WARNING,
+				if(bigstat_one(fsfd, p->bs_ino, p) < 0) {
+				    mlog(MLOG_WARNING,
 					  _("failed to get bulkstat information for inode %llu\n"),
-					  p->bs_ino );
+					  p->bs_ino);
 				    continue;
 				}
-				if ( !p->bs_nlink || !p->bs_mode || !p->bs_ino ) {
-					mlog( MLOG_TRACE,
+				if (!p->bs_nlink || !p->bs_mode || !p->bs_ino) {
+					mlog(MLOG_TRACE,
 					      _("failed to get valid bulkstat information for inode %llu\n"),
-					      p->bs_ino );
+					      p->bs_ino);
 					continue;
 				}
 			}
 
-			if ( ( p->bs_mode & S_IFMT ) == S_IFDIR ) {
-				if ( ! ( selector & BIGSTAT_ITER_DIR )){
+			if ((p->bs_mode & S_IFMT) == S_IFDIR) {
+				if (!(selector & BIGSTAT_ITER_DIR)){
 					continue;
 				}
 			} else {
-				if ( ! ( selector & BIGSTAT_ITER_NONDIR )){
+				if (!(selector & BIGSTAT_ITER_NONDIR)){
 					continue;
 				}
 			}
-			rval = ( * fp )( cb_arg1, fshandlep, fsfd, p );
-			if ( rval ) {
+			rval = (*fp)(cb_arg1, fshandlep, fsfd, p);
+			if (rval) {
 				*statp = rval;
 				return 0;
 			}
-			if ( pfp ) ( pfp )( PREEMPT_PROGRESSONLY );
+			if (pfp) (pfp)(PREEMPT_PROGRESSONLY);
 		}
 
-		if ( pfp && (++bulkstatcnt % 10) == 0 &&
-		     ( pfp )( PREEMPT_FULL )) {
+		if (pfp && (++bulkstatcnt % 10) == 0 &&
+		     (pfp)(PREEMPT_FULL)) {
 			return EINTR;
 		}
 
 		if (seekfp) {
 			lastino = seekfp(seek_arg1, lastino);
 			if (lastino == INO64MAX) {
-				mlog( MLOG_DEBUG,
+				mlog(MLOG_DEBUG,
 				      "bulkstat seeked to EOS\n");
 				return 0;
 			}
-			
-			mlog( MLOG_DEBUG,
+
+			mlog(MLOG_DEBUG,
 			      "bulkstat seeked to %llu\n", lastino);
 
 			lastino = (lastino > 0) ? lastino - 1 : 0;
 		}
 
-		mlog( MLOG_NITTY + 1,
-		      "calling bulkstat\n" );
+		mlog(MLOG_NITTY + 1,
+		      "calling bulkstat\n");
 	}
 
 	saved_errno = errno;
 
-	mlog( MLOG_NORMAL,
+	mlog(MLOG_NORMAL,
 	      _("syssgi( SGI_FS_BULKSTAT ) on fsroot failed: %s\n"),
-	      strerror( saved_errno ));
+	      strerror(saved_errno));
 
 	return saved_errno;
 }
 
 /* ARGSUSED */
-intgen_t
-bigstat_one( intgen_t fsfd,
+int
+bigstat_one(int fsfd,
 	     xfs_ino_t ino,
-	     xfs_bstat_t *statp )
+	     struct xfs_bstat *statp)
 {
-        xfs_fsop_bulkreq_t bulkreq;
-	intgen_t count = 0;
+	struct xfs_fsop_bulkreq bulkreq;
+	int count = 0;
 
-	ASSERT( ino > 0 );
-        bulkreq.lastip = (__u64 *)&ino;
-        bulkreq.icount = 1;
-        bulkreq.ubuffer = statp;
-        bulkreq.ocount = &count;
+	assert(ino > 0);
+	bulkreq.lastip = (__u64 *)&ino;
+	bulkreq.icount = 1;
+	bulkreq.ubuffer = statp;
+	bulkreq.ocount = &count;
 	return xfsctl(NULL, fsfd, XFS_IOC_FSBULKSTAT_SINGLE, &bulkreq);
 }
 
 /* call the given callback for each inode group in the filesystem.
  */
 #define INOGRPLEN	256
-intgen_t
-inogrp_iter( intgen_t fsfd,
-	     intgen_t ( * fp )( void *arg1,
-				intgen_t fsfd,
-				xfs_inogrp_t *inogrp ),
+int
+inogrp_iter(int fsfd,
+	     int (*fp)(void *arg1,
+				int fsfd,
+				struct xfs_inogrp *inogrp),
 	     void * arg1,
-	     intgen_t *statp )
+	     int *statp)
 {
 	xfs_ino_t lastino;
-	intgen_t inogrpcnt;
-	xfs_inogrp_t *igrp;
-        xfs_fsop_bulkreq_t bulkreq;
+	int inogrpcnt;
+	struct xfs_inogrp *igrp;
+	struct xfs_fsop_bulkreq bulkreq;
 
 	/* stat set with return from callback func */
 	*statp = 0;
 
-	igrp = malloc(INOGRPLEN * sizeof(xfs_inogrp_t));
+	igrp = malloc(INOGRPLEN * sizeof(struct xfs_inogrp));
 	if (!igrp) {
 		mlog(MLOG_NORMAL | MLOG_ERROR,
 		     _("malloc of stream context failed (%d bytes): %s\n"),
-		     INOGRPLEN * sizeof(xfs_inogrp_t),
+		     INOGRPLEN * sizeof(struct xfs_inogrp),
 		     strerror(errno));
 		return -1;
 	}
@@ -298,17 +302,17 @@ inogrp_iter( intgen_t fsfd,
 	bulkreq.ubuffer = igrp;
 	bulkreq.ocount = &inogrpcnt;
 	while (!ioctl(fsfd, XFS_IOC_FSINUMBERS, &bulkreq)) {
-		xfs_inogrp_t *p, *endp;
+		struct xfs_inogrp *p, *endp;
 
-		if ( inogrpcnt == 0 ) {
+		if (inogrpcnt == 0) {
 			free(igrp);
 			return 0;
 		}
-		for ( p = igrp, endp = igrp + inogrpcnt ; p < endp ; p++ ) {
-			intgen_t rval;
+		for (p = igrp, endp = igrp + inogrpcnt; p < endp; p++) {
+			int rval;
 
-			rval = ( * fp )( arg1, fsfd, p );
-			if ( rval ) {
+			rval = (*fp)(arg1, fsfd, p);
+			if (rval) {
 				*statp = rval;
 				free(igrp);
 				return 0;
@@ -332,126 +336,126 @@ inogrp_iter( intgen_t fsfd,
  *
  * caller may supply a dirent buffer. if not, will malloc one
  */
-intgen_t
-diriter( jdm_fshandle_t *fshandlep,
-	 intgen_t fsfd,
-	 xfs_bstat_t *statp,
-	 intgen_t ( *cbfp )( void *arg1,
+int
+diriter(jdm_fshandle_t *fshandlep,
+	 int fsfd,
+	 struct xfs_bstat *statp,
+	 int (*cbfp)(void *arg1,
 			     jdm_fshandle_t *fshandlep,
-			     intgen_t fsfd,
-			     xfs_bstat_t *statp,
-			     char *namep ),
+			     int fsfd,
+			     struct xfs_bstat *statp,
+			     char *namep),
 	 void *arg1,
-	 intgen_t *cbrvalp,
+	 int *cbrvalp,
 	 char *usrgdp,
-	 size_t usrgdsz )
+	 size_t usrgdsz)
 {
 	size_t gdsz;
 	struct dirent *gdp;
-	intgen_t fd;
-	intgen_t gdcnt;
-	intgen_t scrval;
-	intgen_t cbrval;
+	int fd;
+	int gdcnt;
+	int scrval;
+	int cbrval;
 
-	if ( usrgdp ) {
-		ASSERT( usrgdsz >= sizeof( struct dirent ) );
+	if (usrgdp) {
+		assert(usrgdsz >= sizeof(struct dirent));
 		gdsz = usrgdsz;
-		gdp = ( struct dirent * )usrgdp;
+		gdp = (struct dirent *)usrgdp;
 	} else {
 		gdsz = pgsz;
-		gdp = ( struct dirent * )malloc( gdsz );
-		ASSERT( gdp );
+		gdp = (struct dirent *)malloc(gdsz);
+		assert(gdp);
 	}
 
 	/* open the directory
 	 */
-	fd = jdm_open( fshandlep, statp, O_RDONLY );
-	if ( fd < 0 ) {
-		mlog( MLOG_NORMAL,
+	fd = jdm_open(fshandlep, statp, O_RDONLY);
+	if (fd < 0) {
+		mlog(MLOG_NORMAL,
 		      _("WARNING: unable to open directory ino %llu: %s\n"),
 		      statp->bs_ino,
-		      strerror( errno ));
+		      strerror(errno));
 		*cbrvalp = 0;
-		if ( ! usrgdp ) {
-			free( ( void * )gdp );
+		if (!usrgdp) {
+			free((void *)gdp);
 		}
 		return -1;
 	}
-	ASSERT( ( statp->bs_mode & S_IFMT ) == S_IFDIR );
+	assert((statp->bs_mode & S_IFMT) == S_IFDIR);
 
 	/* lots of buffering done here, to achieve OS-independence.
 	 * if proves to be to much overhead, can streamline.
 	 */
 	scrval = 0;
 	cbrval = 0;
-	for ( gdcnt = 1 ; ; gdcnt++ ) {
+	for (gdcnt = 1 ; ; gdcnt++) {
 		struct dirent *p;
-		intgen_t nread;
+		int nread;
 		register size_t reclen;
 
-		ASSERT( scrval == 0 );
-		ASSERT( cbrval == 0 );
+		assert(scrval == 0);
+		assert(cbrval == 0);
+
+		nread = getdents_wrap(fd, (char *)gdp, gdsz);
 
-		nread = getdents_wrap( fd, (char *)gdp, gdsz );
-		
 		/* negative count indicates something very bad happened;
 		 * try to gracefully end this dir.
 		 */
-		if ( nread < 0 ) {
-			mlog( MLOG_NORMAL,
+		if (nread < 0) {
+			mlog(MLOG_NORMAL,
 			      _("WARNING: unable to read dirents (%d) for "
 			      "directory ino %llu: %s\n"),
 			      gdcnt,
 			      statp->bs_ino,
-			      strerror( errno ));
+			      strerror(errno));
 			nread = 0; /* pretend we are done */
 		}
 
 		/* no more directory entries: break;
 		 */
-		if ( nread == 0 ) {
+		if (nread == 0) {
 			break;
 		}
 
 		/* translate and invoke cb each entry: skip "." and "..".
 		 */
-		for ( p = gdp,
-		      reclen = ( size_t )p->d_reclen
+		for (p = gdp,
+		      reclen = (size_t)p->d_reclen
 		      ;
 		      nread > 0
 		      ;
-		      nread -= ( intgen_t )reclen,
-		      ASSERT( nread >= 0 ),
-		      p = ( struct dirent * )( ( char * )p + reclen ),
-		      reclen = ( size_t )p->d_reclen ) {
-			xfs_bstat_t statbuf;
-			ASSERT( scrval == 0 );
-			ASSERT( cbrval == 0 );
+		      nread -= (int)reclen,
+		      assert(nread >= 0),
+		      p = (struct dirent *)((char *)p + reclen),
+		      reclen = (size_t)p->d_reclen) {
+			struct xfs_bstat statbuf;
+			assert(scrval == 0);
+			assert(cbrval == 0);
 
 			/* skip "." and ".."
 			 */
-			if ( *( p->d_name + 0 ) == '.'
+			if (*(p->d_name + 0) == '.'
 			     &&
-			     ( *( p->d_name + 1 ) == 0
+			     (*(p->d_name + 1) == 0
 			       ||
-			       ( *( p->d_name + 1 ) == '.'
+			       (*(p->d_name + 1) == '.'
 				 &&
-				 *( p->d_name + 2 ) == 0 ))) {
+				 *(p->d_name + 2) == 0))) {
 				continue;
 			}
 
 			/* use bigstat
 			 */
-			scrval = bigstat_one( fsfd,
+			scrval = bigstat_one(fsfd,
 					      p->d_ino,
-					      &statbuf );
-			if ( scrval ) {
-				mlog( MLOG_NORMAL,
+					      &statbuf);
+			if (scrval) {
+				mlog(MLOG_NORMAL,
 				      _("WARNING: could not stat "
 				      "dirent %s ino %llu: %s\n"),
 				      p->d_name,
-				      ( xfs_ino_t )p->d_ino,
-				      strerror( errno ));
+				      (xfs_ino_t)p->d_ino,
+				      strerror(errno));
 				scrval = 0;
 				continue;
 			}
@@ -460,45 +464,45 @@ diriter( jdm_fshandle_t *fshandlep,
 			 * occupied more than 32 bits, warn and skip.
 			 */
 #ifndef __USE_LARGEFILE64
-			if ( statbuf.bs_ino > ( xfs_ino_t )INOMAX ) {
-				mlog( MLOG_NORMAL,
+			if (statbuf.bs_ino > (xfs_ino_t)INOMAX) {
+				mlog(MLOG_NORMAL,
 				      _("WARNING: unable to process dirent %s: "
 				      "ino %llu too large\n"),
 				      p->d_name,
-				      ( xfs_ino_t )p->d_ino );
+				      (xfs_ino_t)p->d_ino);
 				continue;
 			}
 #endif
 
 			/* invoke the callback
 			 */
-			cbrval = ( * cbfp )( arg1,
+			cbrval = (*cbfp)(arg1,
 					     fshandlep,
 					     fsfd,
 					     &statbuf,
-					     p->d_name );
+					     p->d_name);
 
 			/* abort the iteration if the callback returns non-zero
 			 */
-			if ( cbrval ) {
+			if (cbrval) {
 				break;
 			}
 		}
 
-		if ( scrval || cbrval ) {
+		if (scrval || cbrval) {
 			break;
 		}
 	}
 
-	( void )close( fd );
-	if ( ! usrgdp ) {
-		free( ( void * )gdp );
+	(void)close(fd);
+	if (!usrgdp) {
+		free((void *)gdp);
 	}
 
-	if ( scrval ) {
+	if (scrval) {
 		*cbrvalp = 0;
 		return -1;
-	} else if ( cbrval ) {
+	} else if (cbrval) {
 		*cbrvalp = cbrval;
 		return 1;
 	} else {
@@ -507,8 +511,8 @@ diriter( jdm_fshandle_t *fshandlep,
 	}
 }
 
-int 
-cvtnum( int blocksize, char *s )
+int
+cvtnum(int blocksize, char *s)
 {
 	int i;
 	char *sp;
@@ -526,48 +530,3 @@ cvtnum( int blocksize, char *s )
 		return 1024 * 1024 * i;
 	return -1;
 }
-
-void
-fold_init( fold_t fold, char *infostr, char c )
-{
-	size_t infolen;
-	size_t dashlen;
-	size_t predashlen;
-	size_t postdashlen;
-	char *p;
-	char *endp;
-	ix_t cnt;
-
-	ASSERT( sizeof( fold_t ) == FOLD_LEN + 1 );
-
-	infolen = strlen( infostr );
-	if ( infolen > FOLD_LEN - 4 ) {
-		infolen = FOLD_LEN - 4;
-	}
-	dashlen = FOLD_LEN - infolen - 3;
-	predashlen = dashlen / 2;
-	postdashlen = dashlen - predashlen;
-
-	p = &fold[ 0 ];
-	endp = &fold[ sizeof( fold_t ) - 1 ];
-
-	ASSERT( p < endp );
-	*p++ = ' ';
-	for ( cnt = 0 ; cnt < predashlen && p < endp ; cnt++, p++ ) {
-		*p = c;
-	}
-	ASSERT( p < endp );
-	*p++ = ' ';
-	ASSERT( p < endp );
-	ASSERT( p + infolen < endp );
-	strcpy( p, infostr );
-	p += infolen;
-	ASSERT( p < endp );
-	*p++ = ' ';
-	ASSERT( p < endp );
-	for ( cnt = 0 ; cnt < postdashlen && p < endp ; cnt++, p++ ) {
-		*p = c;
-	}
-	ASSERT( p <= endp );
-	*p = 0;
-}
