@@ -19,8 +19,15 @@
 #include <xfs/xfs.h>
 #include <xfs/jdm.h>
 
+#include <stdio.h>
+#include <fcntl.h>
+#include <unistd.h>
+#include <stdlib.h>
 #include <ncurses.h>
 #include <sys/mman.h>
+#include <sys/stat.h>
+#include <string.h>
+#include <uuid/uuid.h>
 
 #include "types.h"
 #include "mlog.h"
@@ -32,6 +39,7 @@
 #include "list.h"
 #include "invidx.h"
 #include "stobj.h"
+#include "timeutil.h"
 
 invidx_fileinfo_t *invidx_file;
 int invidx_numfiles;
@@ -39,7 +47,7 @@ int invidx_numfiles;
 extern stobj_fileinfo_t *stobj_file;
 extern int stobj_numfiles;
 
-static void stobj_makefname_len( char *fname, int fname_len );
+static void stobj_makefname_len(char *fname, int fname_len);
 
 menu_ops_t invidx_ops = {
     NULL,
@@ -86,7 +94,7 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 	}
 	mark_all_children_commited(current);
 
-	if ( invidx_file[fidx].counter->ic_curnum > 1 ) {
+	if (invidx_file[fidx].counter->ic_curnum > 1) {
 	    memmove(&inv_entry[idx],
 		    &inv_entry[idx + 1],
 		    (sizeof(invt_entry_t) * (invidx_file[fidx].counter->ic_curnum - idx - 1)));
@@ -148,7 +156,7 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 				&ses,
 				&strms,
 				&mfiles);
-		    
+
 		    insert_stobj_into_stobjfile(dst_fileidx,
 		    		stobj_filename,
 				stobj_fd,
@@ -172,7 +180,7 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 		tmp_parent = ((data_t *)(dst_n->data))->parent;
 		while(dst_n != NULL) {
 		    node_t *tmp_n1;
-		    
+
 		    dst_d = dst_n->data;
 
 		    /* close affected invidx file and stobj files */
@@ -213,10 +221,10 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 		else {
 		    dest = invidx_file[dst_fileidx].data[invidx_file[dst_fileidx].counter->ic_curnum - 1] + 1;
 		}
-		
+
 		/* copy new data to mmap */
 		memmove(dest, inv_entry, sizeof(*inv_entry));
-	    
+
 		/* increment counter */
 		invidx_file[dst_fileidx].counter->ic_curnum++;
 
@@ -241,13 +249,13 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 		    put_error("Error: unable to copy stobj file: file exists");
 		    return 0;
 		}
-	    
+
 		snprintf(cmd, sizeof(cmd), "cp %s %s", stobjfile, dst_stobjfile);
 		if(system(cmd) != 0) {
 		    put_error("Error: unable to copy stobj file: cp failed");
 		    return 0;
 		}
-	    
+
 		open_stobj(dst_stobjfile);
 		return 0;
 	    }
@@ -311,13 +319,13 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 		put_error("Error: unable to copy stobj file: file exists");
 		return 0;
 	    }
-	    
+
 	    snprintf(cmd, sizeof(cmd), "cp %s %s", stobjfile, dst_stobjfile);
 	    if(system(cmd) != 0) {
 		put_error("Error: unable to copy stobj file: cp failed");
 		return 0;
 	    }
-	    
+
 	    open_stobj(dst_stobjfile);
 	    return 0;
 	}
@@ -327,7 +335,7 @@ invidx_commit(WINDOW *win, node_t *current, node_t *list)
 }
 
 int
-create_stobjfile(int invidx_fileidx, char *filename, int fname_len, 
+create_stobjfile(int invidx_fileidx, char *filename, int fname_len,
 	invt_seshdr_t *hdr, invt_session_t *ses, invt_stream_t *strms,
 	invt_mediafile_t *mfiles)
 {
@@ -378,7 +386,7 @@ read_stobj_info(int fd, int idx, invt_seshdr_t **out_hdr,
 	else {
 	    mfiles = NULL;
 	}
-    }    
+    }
     else {
 	strms = NULL;
 	mfiles = NULL;
@@ -388,7 +396,7 @@ read_stobj_info(int fd, int idx, invt_seshdr_t **out_hdr,
     *out_ses = ses;
     *out_strms = strms;
     *out_mfiles = mfiles;
-    
+
     return fd;
 }
 
@@ -417,27 +425,6 @@ delete_stobj_entries(int fd, int deletepos)
     return 0;
 }
 
-int
-find_invidx_insert_point(int fd, time_t sh_time)
-{
-    int i;
-    invt_counter_t cnt;
-    invt_entry_t tmpentry;
-
-    lseek(fd, 0, SEEK_SET);
-    read_n_bytes(fd, (char *)&cnt, sizeof(cnt), "invidx file");
-
-    for(i = 0; i < cnt.ic_curnum; i++) {
-	read_n_bytes(fd, (char *)&tmpentry, sizeof(tmpentry), "invidx file");
-	if(tmpentry.ie_timeperiod.tp_start <= sh_time
-	   && tmpentry.ie_timeperiod.tp_end >= sh_time) {
-	    break;
-	}
-    }
-
-    return i;
-}
-
 int
 find_stobj_insert_point(int fd, invt_seshdr_t *hdr)
 {
@@ -462,8 +449,8 @@ int
 update_invidx_entry(int fd, char *filename, int stobj_fd)
 {
     int i;
-    time_t start_time;
-    time_t end_time;
+    time32_t start_time;
+    time32_t end_time;
     invt_counter_t cnt;
     invt_seshdr_t hdr;
     invt_sescounter_t sescnt;
@@ -474,9 +461,9 @@ update_invidx_entry(int fd, char *filename, int stobj_fd)
     /* find the start and stop in stobj file */
     lseek(stobj_fd, 0, SEEK_SET);
     read_n_bytes(stobj_fd, &sescnt, sizeof(sescnt), "stobj file");
-    
+
     memset(&hdr, 0, sizeof(hdr));
-    first_offset = STOBJ_OFFSET(0,0);
+    first_offset = STOBJ_OFFSET(0, 0);
     lseek(stobj_fd, first_offset, SEEK_SET);
     read_n_bytes(stobj_fd, &hdr, sizeof(hdr), "stobj file");
     start_time = hdr.sh_time;
@@ -501,7 +488,7 @@ update_invidx_entry(int fd, char *filename, int stobj_fd)
 	    return i;
 	}
     }
-    
+
     entry.ie_timeperiod.tp_start = start_time;
     entry.ie_timeperiod.tp_end = end_time;
     strcpy(entry.ie_filename, filename);
@@ -547,7 +534,7 @@ insert_stobj_into_stobjfile(int invidx_fileidx, char *filename, int fd,
 
 	for(i = pos; i < sescnt.ic_curnum; i++) {
 	    read_stobj_info(fd, i, &s_hdr, &s_ses, &s_strms, &s_mfiles);
-	    
+
 	    insert_stobj_into_stobjfile(invidx_fileidx, new_filename, new_fd, s_hdr, s_ses, s_strms, s_mfiles);
 
 	    free(s_hdr); free(s_ses); free(s_strms); free(s_mfiles);
@@ -560,7 +547,7 @@ insert_stobj_into_stobjfile(int invidx_fileidx, char *filename, int fd,
     }
 
     /* stobj file not full, just insert the entry */
-    hdr->sh_sess_off = STOBJ_OFFSET( sescnt.ic_maxnum, pos);
+    hdr->sh_sess_off = STOBJ_OFFSET(sescnt.ic_maxnum, pos);
     hdr->sh_streams_off = sescnt.ic_eof;
 
     /* for seshdr: malloc buffer, copy new entry into buffer, read file entries into buffer, write the lot out */
@@ -597,31 +584,31 @@ insert_stobj_into_stobjfile(int invidx_fileidx, char *filename, int fd,
 }
 
 static void
-stobj_makefname_len( char *fname, int fname_len )
-{	
+stobj_makefname_len(char *fname, int fname_len)
+{
     /* come up with a new unique name */
     uuid_t	fn;
     char	str[UUID_STR_LEN + 1];
 
-    uuid_generate( fn );
-    uuid_unparse( fn, str );
+    uuid_generate(fn);
+    uuid_unparse(fn, str);
 
     snprintf(fname, fname_len, "%s/%s.StObj", inventory_path, str);
 }
 
 int
-stobj_create( char *fname )
+stobj_create(char *fname)
 {
-    int fd;	
+    int fd;
     invt_sescounter_t sescnt;
 
     /* create the new storage object */
-    if (( fd = open( fname, O_RDWR | O_EXCL | O_CREAT, S_IRUSR|S_IWUSR )) < 0 ) {
+    if ((fd = open(fname, O_RDWR | O_EXCL | O_CREAT, S_IRUSR|S_IWUSR)) < 0) {
 	return -1;
     }
-    
-    INVLOCK( fd, LOCK_EX );
-    fchmod( fd, INV_PERMS );
+
+    INVLOCK(fd, LOCK_EX);
+    fchmod(fd, INV_PERMS);
 
     memset(&sescnt, 0, sizeof(sescnt));
     sescnt.ic_vernum = INV_VERSION;
@@ -630,53 +617,53 @@ stobj_create( char *fname )
     sescnt.ic_eof = SC_EOF_INITIAL_POS;
 
     lseek(fd, 0, SEEK_SET);
-    write_n_bytes ( fd, (char *)&sescnt, sizeof(sescnt), "new stobj file" );
-	
-    INVLOCK( fd, LOCK_UN );
+    write_n_bytes (fd, (char *)&sescnt, sizeof(sescnt), "new stobj file");
+
+    INVLOCK(fd, LOCK_UN);
     return fd;
 }
 
-intgen_t
-stobj_put_streams( int fd, invt_seshdr_t *hdr, invt_session_t *ses, 
+int
+stobj_put_streams(int fd, invt_seshdr_t *hdr, invt_session_t *ses,
 		   invt_stream_t *strms,
-		   invt_mediafile_t *mfiles )
+		   invt_mediafile_t *mfiles)
 {
-    u_int	nstm	= ses->s_cur_nstreams;
+    uint	nstm	= ses->s_cur_nstreams;
     off64_t	off	= hdr->sh_streams_off;
-    off64_t	mfileoff= off + (off64_t)( nstm * sizeof( invt_stream_t ) );
-    u_int	nmfiles = 0;
-    u_int	i,j;
+    off64_t	mfileoff= off + (off64_t)(nstm * sizeof(invt_stream_t));
+    uint	nmfiles = 0;
+    uint	i, j;
 
     /* fix the offsets in streams */
-     for ( i = 0; i < nstm; i++ ) {
-	strms[i].st_firstmfile = mfileoff + (off64_t) ((size_t) nmfiles * sizeof( invt_mediafile_t ) );
+     for (i = 0; i < nstm; i++) {
+	strms[i].st_firstmfile = mfileoff + (off64_t) ((size_t) nmfiles * sizeof(invt_mediafile_t));
 	/* now fix the offsets in mediafiles */
-	for ( j = 0; j < strms[i].st_nmediafiles; j++ ) {
-			
+	for (j = 0; j < strms[i].st_nmediafiles; j++) {
+
 	    /* no need to fix the last element's next ptr */
-	    if ( j < strms[i].st_nmediafiles - 1 )
-		mfiles[ nmfiles + j ].mf_nextmf =  strms[i].st_firstmfile + (off64_t) ((j+1) * sizeof( invt_mediafile_t ));
+	    if (j < strms[i].st_nmediafiles - 1)
+		mfiles[nmfiles + j].mf_nextmf =  strms[i].st_firstmfile + (off64_t) ((j+1) * sizeof(invt_mediafile_t));
 
 	    /* no need to fix the first element's prev ptr */
-	    if ( j )
-		mfiles[ nmfiles + j ].mf_prevmf = strms[i].st_firstmfile + (off64_t) ((j-1) * sizeof( invt_mediafile_t ));
+	    if (j)
+		mfiles[nmfiles + j].mf_prevmf = strms[i].st_firstmfile + (off64_t) ((j-1) * sizeof(invt_mediafile_t));
 	}
 
-	/* adjust the offsets of the first and the last elements 
+	/* adjust the offsets of the first and the last elements
 	   in the mediafile chain */
-	mfiles[ nmfiles ].mf_prevmf = 0;
+	mfiles[nmfiles].mf_prevmf = 0;
 	nmfiles += strms[i].st_nmediafiles;
-	mfiles[ nmfiles - 1 ].mf_nextmf = 0;		
+	mfiles[nmfiles - 1].mf_nextmf = 0;
     }
 
     /* first put the streams. hdr already points at the right place */
     lseek(fd, off, SEEK_SET);
-    write_n_bytes( fd, strms, nstm * sizeof( invt_stream_t ), "stobj file" );
+    write_n_bytes(fd, strms, nstm * sizeof(invt_stream_t ), "stobj file");
 
     lseek(fd, mfileoff, SEEK_SET);
-    write_n_bytes( fd, mfiles, nmfiles * sizeof( invt_mediafile_t ), "stobj file" );
+    write_n_bytes(fd, mfiles, nmfiles * sizeof(invt_mediafile_t ), "stobj file");
 
-    return 1;	
+    return 1;
 }
 
 /*ARGSUSED*/
@@ -718,11 +705,11 @@ invidx_highlight(WINDOW *win, node_t *current, node_t *list)
     snprintf(txt, sizeof(txt), "path:  %s", invtentry->ie_filename);
     put_info_line(1, txt);
 
-    snprintf(txt, sizeof(txt), "start: %s", ctime((time_t*)&invtentry->ie_timeperiod.tp_start));
+    snprintf(txt, sizeof(txt), "start: %s", ctime32(&invtentry->ie_timeperiod.tp_start));
     txt[strlen(txt) - 1] = '\0';
     put_info_line(2, txt);
 
-    snprintf(txt, sizeof(txt), "end:   %s", ctime((time_t*)&invtentry->ie_timeperiod.tp_end));
+    snprintf(txt, sizeof(txt), "end:   %s", ctime32(&invtentry->ie_timeperiod.tp_end));
     txt[strlen(txt) - 1] = '\0';
     put_info_line(3, txt);
 
@@ -757,7 +744,7 @@ invidx_undelete(WINDOW *win, node_t *current, node_t *list)
 
 /*ARGSUSED*/
 int
-invidx_prune(char *mountpt, uuid_t *uuidp, time_t prunetime, node_t *node, node_t *list)
+invidx_prune(char *mountpt, uuid_t *uuidp, time32_t prunetime, node_t *node, node_t *list)
 {
     data_t *d;
     invt_entry_t *invidx_entry;
@@ -784,7 +771,7 @@ find_invidx_node(node_t *list, int inv_fileidx)
 {
     node_t *n;
     data_t *d;
-    
+
     n = list;
     while(n != NULL && n->data != NULL) {
     	d = n->data;
@@ -796,7 +783,7 @@ find_invidx_node(node_t *list, int inv_fileidx)
 	}
 	n = n->next;
     }
-    
+
     return NULL;
 }
 
@@ -847,7 +834,7 @@ find_invidx_insert_pos(int fidx, invt_entry_t *inv_entry)
 	next_entry = invidx_file[fidx].data[i+1];
 
 	if(inv_entry->ie_timeperiod.tp_start > entry->ie_timeperiod.tp_end
-	   && inv_entry->ie_timeperiod.tp_end < next_entry->ie_timeperiod.tp_start ) {
+	   && inv_entry->ie_timeperiod.tp_end < next_entry->ie_timeperiod.tp_start) {
 	    return i;
 	}
     }
@@ -929,7 +916,7 @@ generate_invidx_menu(char * inv_path, node_t *startnode, int level, char *idxFil
 	return startnode;
     }
 
-    invidx_entry = (invt_entry_t *)( invidx_file[idx].mapaddr + sizeof(invt_counter_t));
+    invidx_entry = (invt_entry_t *)(invidx_file[idx].mapaddr + sizeof(invt_counter_t));
 
     n = startnode;
     for (i=0; i < invidx_file[idx].counter->ic_curnum; i++) {
@@ -960,7 +947,7 @@ generate_invidx_menu(char * inv_path, node_t *startnode, int level, char *idxFil
 
 	add_invidx_data(idx, &(invidx_entry[i]));
 	stobjname = GetNameOfStobj(inv_path, invidx_entry[i].ie_filename);
-	n = generate_stobj_menu( n, level + 1, stobjname );
+	n = generate_stobj_menu(n, level + 1, stobjname);
 	free(stobjname);
     }
 
@@ -1014,7 +1001,7 @@ remmap_invidx(int fidx, int num)
 
     nEntries = invidx_file[fidx].counter->ic_curnum;
 
-    munmap( invidx_file[fidx].mapaddr,
+    munmap(invidx_file[fidx].mapaddr,
 	    (nEntries * sizeof(invt_entry_t)) + sizeof(invt_counter_t));
 
     /* need to lseek on the file to grow it to the right size - no autogrow on linux */
@@ -1055,7 +1042,7 @@ open_invidx(char *idxFileName)
     invt_counter_t header;
 
     errno=0;
-    fd = open_and_lock( idxFileName, FILE_WRITE, wait_for_locks );
+    fd = open_and_lock(idxFileName, FILE_WRITE, wait_for_locks);
     if (fd < 0) {
         return fd;
     }
@@ -1066,7 +1053,7 @@ open_invidx(char *idxFileName)
 	exit(1);
     }
 
-    read_n_bytes( fd, &header, sizeof(invt_counter_t), idxFileName);
+    read_n_bytes(fd, &header, sizeof(invt_counter_t), idxFileName);
 
     nEntries = header.ic_curnum;
 
@@ -1088,21 +1075,21 @@ close_invidx(int idx)
 	return 0;
 
     nEntries = invidx_file[idx].counter->ic_curnum;
-    munmap( invidx_file[idx].mapaddr,
-	    (invidx_file[idx].nEntries*sizeof(invt_entry_t)) + sizeof(invt_counter_t) );
+    munmap(invidx_file[idx].mapaddr,
+	    (invidx_file[idx].nEntries*sizeof(invt_entry_t)) + sizeof(invt_counter_t));
 
     if(nEntries != 0 && nEntries != invidx_file[idx].nEntries) {
 	ftruncate(invidx_file[idx].fd,
-		  sizeof(invt_counter_t) + (nEntries * sizeof(invt_entry_t)) );
+		  sizeof(invt_counter_t) + (nEntries * sizeof(invt_entry_t)));
     }
 
-    close( invidx_file[idx].fd );
+    close(invidx_file[idx].fd);
 
     if(nEntries == 0) {
 	unlink(invidx_file[idx].name);
     }
-    free( invidx_file[idx].name );
-    free( invidx_file[idx].data );
+    free(invidx_file[idx].name);
+    free(invidx_file[idx].data);
 
     invidx_file[idx].fd = -1;
     invidx_file[idx].name = NULL;
